PyTorch/Lightning Toolkit
=========================

Datasets
--------

.. currentmodule:: aiaccel.torch.datasets

.. autosummary::
    :toctree: generated/

    CachedDataset
    FileCachedDataset
    HDF5Dataset
    RawHDF5Dataset

Dataset Utilities
-----------------

.. currentmodule:: aiaccel.torch.datasets

.. autosummary::
    :toctree: generated/

    scatter_dataset

Lightning Utilities
-------------------

.. currentmodule:: aiaccel.torch.lightning

.. autosummary::
    :toctree: generated/

    OptimizerLightningModule
    OptimizerConfig
    build_param_groups
    from_pretrained
    ABCIEnvironment

Lightning Datamodules
---------------------

.. currentmodule:: aiaccel.torch.lightning.datamodules

.. autosummary::
    :toctree: generated/

    SingleDataModule

H5py Utilities
--------------

.. currentmodule:: aiaccel.torch.h5py

.. autosummary::
    :toctree: generated/

    HDF5Writer

Functional
----------

.. currentmodule:: aiaccel.torch.functional

.. autosummary::
    :toctree: generated/

    linear_sum_assignment

Learning Rate Schedulers
------------------------

.. currentmodule:: aiaccel.torch.lr_schedulers

.. autosummary::
    :toctree: generated/

    SequentialLR
